<?php
namespace Teknisa\CMP\Modules\Solicitacao\Modules\Relatorios\Controllers;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;

class Cmp06100ProdutosNaoComprados extends \Zeedhi\Framework\Controller\Report {
    protected $entityManager;
    protected $qr2Strategy;
    protected $newCode;
    protected $environment;
    protected $connection;
    protected $stNomeRel;
    protected $filialService;
    protected $reportMapping = [];

    public function __construct($reportService, $entityManager, $qr2Strategy, $newCode, $environment, $connection, $filialService) {
        $this->entityManager       = $entityManager;
        $this->qr2Strategy         = $qr2Strategy;
        $this->reportService       = $reportService;
        $this->newCode             = $newCode;
        $this->environment         = $environment;
        $this->connection          = $connection;
        $this->filialService       = $filialService;
    }

    protected $parameterMappingBirt = [
        "NRORG"         => "P_NRORG",
        "CDREGIAO"      => "P_CDREGIAO",
        "DATAINI"       => "P_DATAINI",
        "DATAFIN"       => "P_DATAFIN",
        "PRODINI"       => "P_PRODINI",
        "PRODFIN"       => "P_PRODFIN",
        "OPERADOR"      => "P_CDOPERADOR",
        "SISTEMA"       => "P_SISTEMA",
        "INDEXREL"      => "P_INDEXREL",
        "CDFILIAL"      => "P_CDFILIAL",
        "CDFILIPROC"    => "P_CDFILIPROC",
        "CDGRUPFILI"    => "P_CDGRUPFILI",
        "RELCOMPRA"     => "P_RELCOMPRA",
        "RELSOLIEXTRA"  => "P_RELSOLIEXTRA",
        "IDITMCONS"     => "P_VD_IDITMCONS",
        "CONSIDERACOMP" => "P_CONSIDERACOMP"
    ];
    
    protected $parameterMappingQr2 = [
        "CDREGIAO"      => "P_CDREGIAO",
        "DATAINI"       => "P_DATAINI",
        "DATAFIN"       => "P_DATAFIN",
        "PRODINI"       => "P_PRODINI",
        "PRODFIN"       => "P_PRODFIN",
        "OPERADOR"      => "P_CDOPERADOR",
        "SISTEMA"       => "P_SISTEMA",
        "INDEXREL"      => "P_IndexRel",
        "CDFILIAL"      => "P_CDFILIAL",
        "CDFILIPROC"    => "P_CDFILIPROC",
        "CDGRUPFILI"    => "P_CDGRUPFILI",
        "RELCOMPRA"     => "P_RELCOMPRA",
        "RELESPECIFICO" => "P_RELESPECIFICO",
        "RELSOLIEXTRA"  => "P_RELSOLIEXTRA",
        "CONSIDERACOMP" => "P_CONSIDERACOMP"
    ];
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        ini_set('default_socket_timeout', 10000);
        ini_set('max_execution_time', 9999);
        
        $row = $request->getRow();
        $cdOperador = $this->environment->getCdOperador();
        
        $row['NRORG'] = $this->environment->getNrOrg();
        
        if($row["CDFILIAL"] == "T") {
            $newFilial = $this->filialService->retornaListaDeFiliais($cdOperador);
            if(is_array($newFilial)) {
                $str = "_";
                foreach($newFilial as $filial) {
                    foreach($filial as $cdfilial) {
                        $str .= $cdfilial . '_';
                    }
                }
                $newFilial = $str;
                $row["CDFILIAL"] = $newFilial;
            }
        }
        
        $this->qr2Strategy->setQr2Type($row['QR2TYPE']);
        $this->stNomeRel = $this->getReportName($row);
        $parameter = $row['STRATEGY'] == 'QR2' ? $this->parameterMappingQr2 : $this->parameterMappingBirt;
        $this->reportMapping[$this->stNomeRel] = [
            'strategy' => $row['STRATEGY'],
            'parameterMapping' => $parameter,
        ];
    }
}
