/*
 TECNISA - TECNOLOGIA EM INFORMTICA

 NOME: CALCULO_MINBCPRODUTO

 DESCRIO:
  PROCEDIMENTO PARA CLCULO DA PAUTA MNIMA FISCAL PARA A BASE DE CLCULO DO PRODUTO.

 CRIAO:
 07/07/2004 - REJANE PRISCILA LEITE

 @C:\WIN_V4\SQL\END_CONV\ORACLE\5204_DFESTPS.SQL
 RAISE_APPLICATION_ERROR(-20501, '', TRUE);
*/
IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
                    WHERE
	        O.NAME = 'CALCULO_MINBCPRODUTO' AND
	        TYPE = 'P' 			             AND
	        U.UID = O.UID                   AND
	        U.NAME = USER)

DROP PROCEDURE CALCULO_MINBCPRODUTO
GO

CREATE PROCEDURE CALCULO_MINBCPRODUTO
    @P_CDEMPRESA       VARCHAR(02),
    @P_TIPOOPER        VARCHAR(02),
    @P_CDINSCESTA      VARCHAR(16),
    @P_IDENTRSAID      VARCHAR(01),
    @P_CDPAIS          VARCHAR(04),
    @P_SGESTADO        VARCHAR(02),
    @P_CDPRODUTO       VARCHAR(10),
    @P_GRUPOFISCAL     VARCHAR(03),
    @P_DTENTRSAID      DATETIME,
    @P_NRLANCTONF      VARCHAR(10),
    @P_CDFILIAL        VARCHAR(04),
    @P_SEQUITPROD      VARCHAR(04),
    @P_VRPRODUTO       NUMERIC(15,5) OUTPUT
AS
   DECLARE @V_VRUNITARIO   NUMERIC(15,5);
   DECLARE @V_QTITEMPROD   NUMERIC(15,5);
   DECLARE @V_VRPAUTAMINBC NUMERIC(15,5);
BEGIN

   SELECT @V_VRUNITARIO = MAX(VRUNITITEM), @V_QTITEMPROD = MAX(QTITEMPROD)
   FROM ITEMPRODUTO
   WHERE CDFILIAL    = @P_CDFILIAL   AND
         NRLANCTONF  = @P_NRLANCTONF AND
         NRSEQITPROD = @P_SEQUITPROD;

   IF @P_GRUPOFISCAL IS NULL BEGIN
      SELECT @V_VRPAUTAMINBC = MAX(VRPRODUTOBC)
      FROM VRPRODBCIMPO
      WHERE CDEMPRESA     = @P_CDEMPRESA    AND
            CDTIPOOPER    = @P_TIPOOPER     AND
            CDINSCESTA    = @P_CDINSCESTA   AND
            IDENTRSAIDOP  = @P_IDENTRSAID   AND
            CDPAIS        = @P_CDPAIS       AND
            SGESTADO      = @P_SGESTADO     AND
            CDPRODUTO     = @P_CDPRODUTO    AND
            CDGRUPOFISC   IS NULL          AND
            DTVALIDBCPR   = (SELECT MAX(DTVALIDBCPR)
                             FROM VRPRODBCIMPO
                             WHERE CDEMPRESA     = @P_CDEMPRESA    AND
                                   CDTIPOOPER    = @P_TIPOOPER     AND
                                   CDINSCESTA    = @P_CDINSCESTA   AND
                                   IDENTRSAIDOP  = @P_IDENTRSAID   AND
                                   CDPAIS        = @P_CDPAIS       AND
                                   SGESTADO      = @P_SGESTADO     AND
                                   CDPRODUTO     = @P_CDPRODUTO    AND
                                   CDGRUPOFISC   IS NULL          AND
                                   DTVALIDBCPR   <= @P_DTENTRSAID);
   END
   ELSE BEGIN
      SELECT @V_VRPAUTAMINBC = MAX(VRPRODUTOBC)
      FROM VRPRODBCIMPO
      WHERE CDEMPRESA     = @P_CDEMPRESA   AND
            CDTIPOOPER    = @P_TIPOOPER    AND
            CDINSCESTA    = @P_CDINSCESTA  AND
            IDENTRSAIDOP  = @P_IDENTRSAID  AND
            CDPAIS        = @P_CDPAIS      AND
            SGESTADO      = @P_SGESTADO    AND
            CDPRODUTO     = @P_CDPRODUTO   AND
            CDGRUPOFISC   = @P_GRUPOFISCAL AND
            DTVALIDBCPR   = (SELECT MAX(DTVALIDBCPR)
                             FROM VRPRODBCIMPO
                             WHERE CDEMPRESA     = @P_CDEMPRESA   AND
                                   CDTIPOOPER    = @P_TIPOOPER    AND
                                   CDINSCESTA    = @P_CDINSCESTA  AND
                                   IDENTRSAIDOP  = @P_IDENTRSAID  AND
                                   CDPAIS        = @P_CDPAIS      AND
                                   SGESTADO      = @P_SGESTADO    AND
                                   CDPRODUTO     = @P_CDPRODUTO   AND
                                   CDGRUPOFISC   = @P_GRUPOFISCAL AND
                                   DTVALIDBCPR  <= @P_DTENTRSAID);
   END;

   IF ROUND(@V_VRUNITARIO,2) < ROUND(@V_VRPAUTAMINBC,2) BEGIN
      SET @P_VRPRODUTO = @V_VRPAUTAMINBC * @V_QTITEMPROD;
   END
   ELSE BEGIN
      SET @P_VRPRODUTO = 0;
   END;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'CALCULO_MINBCPRODUTO','4.05.126';
GO

